==> tuia-news-center-api-0.0.34-xt4-20180522.114858-1-sources.jar: cn/com/duiba/tuia/news/center/dto/AgentAccountDto.java <==
package cn.com.duiba.tuia.news.center.dto;

import java.io.Serializable;
import java.util.Date;

public class AgentAccountDto implements Serializable {
    private static final long serialVersionUID = -2375795281074597182L;

    /** 代理账号Id**/
    private Long id;

    /** 代理账号**/
    private String account;

    /** 代理账号名称**/
    private String accountName;

    /** 代理账号密码**/
    private String pwd;

    /** 代理账号计费类型**/
    private Integer chargeType;

    /**
     * 千次曝光计费
     */
    private Long mexposurePrice;

    /**
     * 分成比例
     */
    private Integer proportion;

    /**
     * 冻结状态
     */
    private Integer freezenStatus;

    /**
     *创建时间
     */
    private Date gmtCreate;

    /**
     * 修改时间
     */
    private Date gmtModified;

    /**
     * 代理联系电话
     */
    private String tel;

    /**
     * 授权开始时间
     */
    private Date gmtStart;

    /**
     * 授权结束时间
     */
    private Date gmtAutoFreezen;

    /**
     * 子账号文章总数
     */
    private Long subAccountArticleCount;

    /**
     *子账号数量
     */
    private Long subAccountCount;

    /**
     * 操作员Id
     */
    private Long optId;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public String getAccount() {
        return account;
    }

    public void setAccount(String account) {
        this.account = account == null ? null : account.trim();
    }

    public String getAccountName() {
        return accountName;
    }

    public void setAccountName(String accountName) {
        this.accountName = accountName == null ? null : accountName.trim();
    }

    public String getPwd() {
        return pwd;
    }

    public void setPwd(String pwd) {
        this.pwd = pwd == null ? null : pwd.trim();
    }

    public Integer getChargeType() {
        return chargeType;
    }

    public void setChargeType(Integer chargeType) {
        this.chargeType = chargeType;
    }

    public Long getMexposurePrice() {
        return mexposurePrice;
    }

    public void setMexposurePrice(Long mexposurePrice) {
        this.mexposurePrice = mexposurePrice;
    }

    public Integer getProportion() {
        return proportion;
    }

    public void setProportion(Integer proportion) {
        this.proportion = proportion;
    }

    public Integer getFreezenStatus() {
        return freezenStatus;
    }

    public void setFreezenStatus(Integer freezenStatus) {
        this.freezenStatus = freezenStatus;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }

    public String getTel() {
        return tel;
    }

    public void setTel(String tel) {
        this.tel = tel == null ? null : tel.trim();
    }

    public Date getGmtStart() {
        return gmtStart;
    }

    public void setGmtStart(Date gmtStart) {
        this.gmtStart = gmtStart;
    }

    public Date getGmtAutoFreezen() {
        return gmtAutoFreezen;
    }

    public void setGmtAutoFreezen(Date gmtAutoFreezen) {
        this.gmtAutoFreezen = gmtAutoFreezen;
    }

    public Long getSubAccountArticleCount() {
        return subAccountArticleCount;
    }

    public void setSubAccountArticleCount(Long subAccountArticleCount) {
        this.subAccountArticleCount = subAccountArticleCount;
    }

    public Long getSubAccountCount() {
        return subAccountCount;
    }

    public void setSubAccountCount(Long subAccountCount) {
        this.subAccountCount = subAccountCount;
    }

    public Long getOptId() {
        return optId;
    }

    public void setOptId(Long optId) {
        this.optId = optId;
    }
}

==> tuia-news-center-api-1.6.6.0-xt-20181127.070424-1-sources.jar: cn/com/duiba/tuia/news/center/dto/AgentAccountDto.java <==
package cn.com.duiba.tuia.news.center.dto;

import java.io.Serializable;
import java.util.Date;

public class AgentAccountDto implements Serializable {
    private static final long serialVersionUID = -2375795281074597182L;

    /** 代理账号Id**/
    private Long id;

    /** 代理账号**/
    private String account;

    /** 代理账号名称**/
    private String accountName;

    /** 代理账号密码**/
    private String pwd;

    /** 代理账号计费类型**/
    private Integer chargeType;

    /**
     * 千次曝光计费
     */
    private Long mexposurePrice;

    /**
     * 分成比例
     */
    private Integer proportion;

    /**
     * 冻结状态
     */
    private Integer freezenStatus;

    /**
     *创建时间
     */
    private Date gmtCreate;

    /**
     * 修改时间
     */
    private Date gmtModified;

    /**
     * 代理联系电话
     */
    private String tel;

    /**
     * 授权开始时间
     */
    private Date gmtStart;

    /**
     * 授权结束时间
     */
    private Date gmtAutoFreezen;

    /**
     * 子账号文章总数
     */
    private Long subAccountArticleCount;

    /**
     *子账号数量
     */
    private Long subAccountCount;

    /**
     * 操作员Id
     */
    private Long optId;

    /**
     * 分成比例
     */
    private Integer finalProportion;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public String getAccount() {
        return account;
    }

    public void setAccount(String account) {
        this.account = account == null ? null : account.trim();
    }

    public String getAccountName() {
        return accountName;
    }

    public void setAccountName(String accountName) {
        this.accountName = accountName == null ? null : accountName.trim();
    }

    public String getPwd() {
        return pwd;
    }

    public void setPwd(String pwd) {
        this.pwd = pwd == null ? null : pwd.trim();
    }

    public Integer getChargeType() {
        return chargeType;
    }

    public void setChargeType(Integer chargeType) {
        this.chargeType = chargeType;
    }

    public Long getMexposurePrice() {
        return mexposurePrice;
    }

    public void setMexposurePrice(Long mexposurePrice) {
        this.mexposurePrice = mexposurePrice;
    }

    public Integer getProportion() {
        return proportion;
    }

    public void setProportion(Integer proportion) {
        this.proportion = proportion;
    }

    public Integer getFreezenStatus() {
        return freezenStatus;
    }

    public void setFreezenStatus(Integer freezenStatus) {
        this.freezenStatus = freezenStatus;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }

    public String getTel() {
        return tel;
    }

    public void setTel(String tel) {
        this.tel = tel == null ? null : tel.trim();
    }

    public Date getGmtStart() {
        return gmtStart;
    }

    public void setGmtStart(Date gmtStart) {
        this.gmtStart = gmtStart;
    }

    public Date getGmtAutoFreezen() {
        return gmtAutoFreezen;
    }

    public void setGmtAutoFreezen(Date gmtAutoFreezen) {
        this.gmtAutoFreezen = gmtAutoFreezen;
    }

    public Long getSubAccountArticleCount() {
        return subAccountArticleCount;
    }

    public void setSubAccountArticleCount(Long subAccountArticleCount) {
        this.subAccountArticleCount = subAccountArticleCount;
    }

    public Long getSubAccountCount() {
        return subAccountCount;
    }

    public void setSubAccountCount(Long subAccountCount) {
        this.subAccountCount = subAccountCount;
    }

    public Long getOptId() {
        return optId;
    }

    public void setOptId(Long optId) {
        this.optId = optId;
    }

    public Integer getFinalProportion() {
        return finalProportion;
    }

    public void setFinalProportion(Integer finalProportion) {
        this.finalProportion = finalProportion;
    }
}
